Learn R Programming

racademyocean (version 0.3.3)

ao_get_academies: Get the list of all academies. It returns the list of all academies in account with a description of them.

Description

Get the list of all academies. It returns the list of all academies in account with a description of them.

Usage

ao_get_academies()

Arguments

Value

tibble with academies