Learn R Programming

racademyocean (version 0.3.3)

ao_get_leaners_from_country: This returns a list of learners from the chosen country

Description

This returns a list of learners from the chosen country

Usage

ao_get_leaners_from_country(country_iso_code)

Value

tibble with leaners

Arguments

country_iso_code

Country iso code

Examples

Run this code
if (FALSE) {
ua_leaners <- ao_get_leaners_from_country("UA")
}

Run the code above in your browser using DataLab