Learn R Programming

racademyocean (version 0.3.3)

ao_get_leaners_registered_at: This returns an array of learners from the Academy, or an empty array, if there is no data.

Description

This returns an array of learners from the Academy, or an empty array, if there is no data.

Usage

ao_get_leaners_registered_at(
  date = Sys.Date() - 1,
  operator = c("=", ">", "<", "="">=", "<=", "<="">")
)

Value

tibble with leaners

Arguments

date

Date string for filter

operator

One of the following comparison operators '=', '>', '<', '>=', '<=', '<>'