Learn R Programming

racademyocean (version 0.3.3)

ao_get_leaners_with_score: This returns a list of learners filtered by their score

Description

This returns a list of learners filtered by their score

Usage

ao_get_leaners_with_score(
  score = 1,
  operator = c(">=", ">", "<", "=", " <=", ">")
)

Value

tibble with leaners

Arguments

score

Filter score the ratio of completed content to available content, across all courses/groups

operator

One of the following comparison operators '=', '>', '<', '>=', '<=', '<>'

Examples

Run this code
if (FALSE) {
leaners <- ao_get_leaners_with_score(
    score = 20,
    operator = '>'
)
}

Run the code above in your browser using DataLab