Learn R Programming

racademyocean (version 0.3.3)

ao_get_learners_churn_at_content: This returns an array of learners who churned at a specific lesson in the course.

Description

This returns an array of learners who churned at a specific lesson in the course.

Usage

ao_get_learners_churn_at_content(course_id, content_id)

Value

tibble with leaners

Arguments

course_id

Course id, you can get it from edit course, from field ‘course URL’

content_id

content id, you can get it from edit content, from field ‘lesson/quiz URL’

Examples

Run this code
if (FALSE) {
churn <- ao_get_learners_churn_at_content(
    course_id = 'ppc-spetsialist-free',
    content_id = 'itogovyy-test'
)
}

Run the code above in your browser using DataLab