Learn R Programming

racademyocean (version 0.3.3)

ao_get_learners_quiz_statistic: Returns statistics about the specified quiz for the specified learner(s).

Description

Returns statistics about the specified quiz for the specified learner(s).

Usage

ao_get_learners_quiz_statistic(email, content_id)

Value

tibble with quize stat

Arguments

email

Search for a users by emails

content_id

ID of the quiz you want to see statistics for

Examples

Run this code
if (FALSE) {
quize_stat <- ao_get_learners_quiz_statistic(
    email = 'mike.p@gmail.com',
    content_id = 'R9eYq5oE6wLoY3NAPmwx'
)
}

Run the code above in your browser using DataLab