Learn R Programming

racademyocean (version 0.3.3)

ao_get_learners_repeated_logins: This returns an array of learners who logged in to the Academy more than one time.

Description

This returns an array of learners who logged in to the Academy more than one time.

Usage

ao_get_learners_repeated_logins()

Arguments

Value

tibble with leaners