Learn R Programming

racademyocean (version 0.3.3)

ao_get_teams: Returns a list of all teams in the academy.

Description

Returns a list of all teams in the academy.

Usage

ao_get_teams()

Arguments

Value

tibble with teams