powered by
This returns an array of learners from the Academy, or an empty array, if there is no data.
ao_get_leaners_registered_at( date = Sys.Date() - 1, operator = c("=", ">", "<", "="">=", "<=", "<="">") )=",>",>
tibble with leaners
Date string for filter
One of the following comparison operators '=', '>', '<', '>=', '<=', '<>'