powered by
This returns a list of learners filtered by their score
ao_get_leaners_with_score( score = 1, operator = c(">=", ">", "<", "=", " <=", ">") )",>
tibble with leaners
Filter score the ratio of completed content to available content, across all courses/groups
One of the following comparison operators '=', '>', '<', '>=', '<=', '<>'
if (FALSE) { leaners <- ao_get_leaners_with_score( score = 20, operator = '>' ) }
Run the code above in your browser using DataLab