powered by
This returns an array of learners who churned at a specific lesson in the course.
ao_get_learners_churn_at_content(course_id, content_id)
tibble with leaners
Course id, you can get it from edit course, from field ‘course URL’
content id, you can get it from edit content, from field ‘lesson/quiz URL’
if (FALSE) { churn <- ao_get_learners_churn_at_content( course_id = 'ppc-spetsialist-free', content_id = 'itogovyy-test' ) }
Run the code above in your browser using DataLab