powered by
Returns statistics about the specified quiz for the specified learner(s).
ao_get_learners_quiz_statistic(email, content_id)
tibble with quize stat
Search for a users by emails
ID of the quiz you want to see statistics for
if (FALSE) { quize_stat <- ao_get_learners_quiz_statistic( email = 'mike.p@gmail.com', content_id = 'R9eYq5oE6wLoY3NAPmwx' ) }
Run the code above in your browser using DataLab